// ----------------------------------------------------------------------------
// Copyright (C) 2014
//              David Freese, W1HKJ
//
// This file is part of flrig.
//
// flrig is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// flrig is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------

#ifndef _IC735_H
#define _IC735_H

#include "ICbase.h"

class RIG_IC735 : public RIG_ICOM {
public:
	RIG_IC735();
	~RIG_IC735(){}

	void selectA();
	void selectB();

	bool check();

	unsigned long int get_vfoA();
	void set_vfoA(unsigned long int);

	unsigned long int get_vfoB(void);
	void set_vfoB(unsigned long int f);

	void set_modeA(int val);
	int  get_modeA();

};

#endif
